#[non_exhaustive]pub struct Block {
pub id: BlockId,
pub story: Story,
pub kind: BlockKind,
pub text: String,
pub style: Option<String>,
pub text_spans: Option<Vec<TextSpan>>,
pub footnote_refs: Vec<u32>,
pub endnote_refs: Vec<u32>,
}Expand description
A normalized textual unit extracted from a DOCX story.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: BlockIdStable identifier for this block.
story: StoryThe story this block belongs to.
kind: BlockKindSemantic kind of block.
text: StringCurrent-view text content for this block.
style: Option<String>Optional style name when mapped by the extractor.
text_spans: Option<Vec<TextSpan>>Optional tracked-change markers aligned to visible text.
footnote_refs: Vec<u32>Referenced footnote ids that appear inline in this block.
endnote_refs: Vec<u32>Referenced endnote ids that appear inline in this block.