#[non_exhaustive]pub struct ExtractOptions {
pub track_changes_mode: TrackChangesMode,
pub include_comments: bool,
pub include_text_spans: bool,
pub include_raw_ids: bool,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.track_changes_mode: TrackChangesModeHow tracked changes should be represented in the output.
include_comments: boolWhether comments and their anchor metadata should be extracted.
include_text_spans: boolWhether blocks should include TextSpan markers.
include_raw_ids: boolWhether raw OOXML revision ids should be preserved.